@@ -1,6 +1,6 @@
-import os, importlib, sqlite3
+import os, importlib, sqlite3, json
 import kaa
-from kaa import consts
+from kaa import consts, utils
 
 class KaaHistoryStorage:
     def __init__(self, filename):
@@ -25,6 +25,7 @@ class History:
 
         storage.add_history(self)
         
+    @utils.ignore_errors
     def close(self):
         ret = self.storage.conn.execute('''
             SELECT id FROM {} ORDER BY id DESC LIMIT ?
@@ -41,10 +42,12 @@ class History:
         storage.conn.execute('''
             CREATE TABLE IF NOT EXISTS {}
                 (id INTEGER PRIMARY KEY,
-                value TEXT)'''.format(self.table_name))
+                value TEXT,
+                info  TEXT)'''.format(self.table_name))
         self.storage = storage
 
-    def add(self, value):
+    @utils.ignore_errors
+    def add(self, value, info=None):
         if not value:
             return
 
@@ -53,18 +56,28 @@ class History:
             (value, ))
 
         self.storage.conn.execute('''
-            INSERT INTO {}(value) VALUES(?)'''.format(self.table_name),
-            (value,))
+            INSERT INTO {}(value, info) VALUES(?, ?)
+            '''.format(self.table_name), (value, json.dumps(info)))
 
         self.storage.conn.commit()
 
     def get(self):
         ret = self.storage.conn.execute('''
-            SELECT value FROM {} ORDER BY id DESC LIMIT ?
+            SELECT value, info FROM {} ORDER BY id DESC LIMIT ?
             '''.format(self.table_name),
             (self.MAX_HISTORY,))
-        return [value for value, in ret]
+        return [(value, json.loads(info)) for value,info in ret]
 
+    @utils.ignore_errors
+    def find(self, value):
+        ret = self.storage.conn.execute('''
+            SELECT info FROM {} WHERE value=?
+            '''.format(self.table_name),
+            (value,))
+
+        for info, in ret:
+            return json.loads(info)
+        
 class Config:
     FILETYPES = [
         'kaa.filetype.default',
@@ -105,13 +118,14 @@ class Config:
         self.hist_storage = KaaHistoryStorage(
             os.path.join(self.HISTDIR, consts.HIST_DBNAME))
 
-        self.hist_files = History('files', self.hist_storage)
-        self.hist_dirs = History('dirs', self.hist_storage)
-        self.hist_searchstr = History('searchstr', self.hist_storage)
-        self.hist_replstr = History('replstr', self.hist_storage)
-        self.hist_grepstr = History('grepstr', self.hist_storage)
-        self.hist_grepdir = History('grepdir', self.hist_storage)
-        self.hist_grepfiles = History('grepfiles', self.hist_storage)
+        self.hist_files = History('filename', self.hist_storage)
+        self.hist_filedisp = History('filedisp', self.hist_storage)
+        self.hist_dirs = History('dirname', self.hist_storage)
+        self.hist_searchstr = History('search_text', self.hist_storage)
+        self.hist_replstr = History('repl_text', self.hist_storage)
+        self.hist_grepstr = History('grep_text', self.hist_storage)
+        self.hist_grepdir = History('grep_dir', self.hist_storage)
+        self.hist_grepfiles = History('grep_filename', self.hist_storage)
 
     def get_mode_packages(self):
         for pkgname in self.FILETYPES:
