@@ -6,6 +6,7 @@ app_keys = {
     f1: 'app.mainmenu',
     f9: 'app.global.prev',
     f10: 'app.global.next',
+    (alt, 'w'): 'menu.window',
 }
 
 # default cursor commands
@@ -72,6 +73,7 @@ edit_command_keys = {
     (ctrl, 'z'): 'edit.undo',
     (ctrl, 'y'): 'edit.redo',
 
+    (alt, 'v'): 'edit.clipboard-history',
 }
 
 addtional_edit_command_keys = {
