@@ -22,16 +22,18 @@ MENUS = {
          
     'RECENTLY-USED-FILES':
         [['Recently used &Files', None, 'file.recently-used-files'],
-         ['Recently used &Dir', None, 'file.recently-used-directories']],
+         ['Recently used &Dirs', None, 'file.recently-used-directories']],
 
     'EDIT':
         [['&Cut', None, 'edit.cut'],
          ['C&opy', None, 'edit.copy'],
          ['&Paste', None, 'edit.paste'],
+         ['Paste &History', None, 'edit.clipboard-history'],
          ['&Undo', None, 'edit.undo'],
          ['&Redo', None, 'edit.redo'],
          ['&Search', None, 'search.showsearch'],
          ['R&eplace', None, 'search.showreplace'],
+         ['Co&mplete', None, 'edit.word-complete'],
          ['[&Convert]', 'EDIT-CONVERT', None]],
 
     'EDIT-CONVERT':
@@ -54,11 +56,18 @@ MENUS = {
          
     'WINDOW':
         [['&Frame list', None, 'app.show-framelist'],
-         ['&Switch file', None, 'editor.switchfile'],
          ['Split &vert', None, 'editor.splitvert'],
          ['Split &horz', None, 'editor.splithorz'],
          ['&Move separator', None, 'editor.moveseparator'],
          ['&Next window', None, 'editor.nextwindow'],
          ['&Prev window', None, 'editor.prevwindow'],		
-         ['&Join window', None, 'editor.joinwindow']]
+         ['&Join window', None, 'editor.joinwindow'],
+         ['[&Switch file]', 'CHANGE-WINDOW', None]],
+
+     'CHANGE-WINDOW':
+         [['&Switch file', None, 'editor.switchfile'],
+          ['&New file here', None, 'file.new-to'],
+          ['&Open file here', None, 'file.open-to'],
+          ['Recently used &Files', None, 'file.recently-used-files-to'],
+          ['Recently used &Dirs', None, 'file.recently-used-directories-to']],
 }
