@@ -129,7 +129,7 @@ class FrameListMode(dialogmode.DialogMode):
         super().init_themes()
         self.themes.append(FrameListThemes)
 
-    def get_cursor_visibility(self):
+    def is_cursor_visible(self):
         return 0   # hide cursor
 
     def on_esc_pressed(self, wnd, event):
