@@ -77,7 +77,7 @@ class MoveSeparatorMode(dialogmode.DialogMode):
         super().init_themes()
         self.themes.append(MoveSeparatorThemes)
 
-    def get_cursor_visibility(self):
+    def is_cursor_visible(self):
         return 0   # hide cursor
 
     def on_esc_pressed(self, wnd, event):
